/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BuilderFrame.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionListener;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextArea;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with builder fields.
 * @author skabore
 */
public class BuilderFrame extends JPanel {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 1828963921261883972L;

    /**
     * The ouput textArea.
     */
    private JTextArea outputTextArea;

    /**
     * The blankSpace label.
     */
    private JLabel blankSpace;

    /**
     * The jPanel1 panel.
     */
    private JPanel jPanel1;

    /**
     * The progressDescription label.
     */
    private JLabel progressDescription;

    /**
     * The progressSent progressBar.
     */
    private JProgressBar progressSent;

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The showDetail button.
     */
    private JButton showDetailButton;

    /**
     * The scroll pane.
     */
    private JScrollPane scroll;

    /**
     * Setps to create a starter jar file.
     */
    private int steps;

    /**
     * The constructor.
     * @param steps, the required steps to create a starter
     */
    public BuilderFrame(final int steps) {

        super();
        this.steps = steps;

        this.contentPanel = getContentPanel();
        ImageIcon icon = getImageIcon();

        this.titlePanel = new JPanel();
        this.textLabel = new JLabel();
        this.iconLabel = new JLabel();
        this.separator = new JSeparator();

        setLayout(new BorderLayout());

        this.titlePanel.setLayout(new BorderLayout());
        this.titlePanel.setBackground(Color.gray);

        this.textLabel.setBackground(Color.gray);
        this.textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        this.textLabel.setText("Build process for creating JOnAS Starter JAR file");
        this.textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        this.textLabel.setOpaque(true);

        this.iconLabel.setBackground(Color.gray);
        if (icon != null) {
            this.iconLabel.setIcon(icon);
        }

        this.titlePanel.add(this.textLabel, BorderLayout.CENTER);
        // titlePanel.add(iconLabel, BorderLayout.EAST);
        this.titlePanel.add(new JLabel("8/" + this.steps + "  "), BorderLayout.EAST);
        this.titlePanel.add(this.separator, BorderLayout.SOUTH);

        add(this.titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(this.contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * Set the progressText value.
     * @param text the text.
     */
    public void setProgressText(final String text) {
        this.progressDescription.setText(text);
    }

    /**
     * Set the progressValue value.
     * @param value the value.
     */
    public void setProgressValue(final int value) {
        this.progressSent.setValue(value);
    }

    /**
     * @return outputTextArea.
     */
    public JTextArea getOutputTextArea() {
        return this.outputTextArea;
    }

    /**
     * @return showDetailButton.
     */
    public JButton getShowDetailButton() {
        return this.showDetailButton;
    }

    /**
     * @return progressDescription
     */
    public JLabel getProgressDescription() {
        return this.progressDescription;
    }

    /**
     * @return contentPanel1.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel();

        this.jPanel1 = new JPanel();
        this.blankSpace = new JLabel();
        this.progressSent = new JProgressBar();
        this.progressDescription = new JLabel();
        this.outputTextArea = new JTextArea(35, 70);
        this.outputTextArea.setEditable(false);
        this.showDetailButton = new JButton("Hide details");

        contentPanel1.setLayout(new BorderLayout());

        this.jPanel1.setLayout(new GridLayout(0, 1));

        this.jPanel1.add(this.blankSpace);

        this.progressDescription.setFont(new Font("MS Sans Serif", 1, 11));
        this.progressDescription.setText("Copying JOnAS server...");
        this.jPanel1.add(this.progressDescription);
        this.progressSent.setStringPainted(false);
        this.progressSent.setPreferredSize(new Dimension(0, 20));
        this.jPanel1.add(this.progressSent);
        contentPanel1.add(this.jPanel1, BorderLayout.NORTH);

        JPanel detail = new JPanel(new SpringLayout());
        JPanel detailButtonPanel = new JPanel(new BorderLayout());
        detailButtonPanel.add(this.showDetailButton, BorderLayout.WEST);

        this.scroll = new JScrollPane(this.outputTextArea);
        detail.add(detailButtonPanel);
        this.scroll.setVisible(true);
        this.scroll.setPreferredSize(new Dimension(840, 450));
        detail.add(this.scroll);
        SpringUtilities.makeCompactGrid(detail, 2, 1, 0, 6, 0, 6);
        contentPanel1.add(detail, BorderLayout.CENTER);

        return contentPanel1;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * Show or hide the build detail process.
     */
    public void showDetail() {
        if (this.showDetailButton.getText().contains("Show")) {
            this.showDetailButton.setText("Hide details");
            this.scroll.setVisible(true);
        } else {
            this.showDetailButton.setText("Show details");
            this.scroll.setVisible(false);
        }
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        this.showDetailButton.addActionListener(listener);
    }
}
