/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FirstFrame.java 20821 2011-02-02 16:59:06Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSeparator;

import org.ow2.jonas.autostart.utility.Utility;

/**
 * This class creates the first frame panel.
 * @author skabore
 */
public class FirstFrame extends JPanel {

    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = -3553836728004356948L;

    /**
     * The welcomeTitle label.
     */
    private JLabel welcomeTitle;

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The iconLabel label.
     */
    private JLabel iconLabel;

    /**
     * The image icon.
     */
    private ImageIcon icon;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * Setps to create a starter jar file.
     */
    private int steps;

    /**
     * Default constructor.
     * @param steps, the required steps to create a starter
     */
    public FirstFrame(final int steps) {
        this.steps = steps;
        this.iconLabel = new JLabel();
        this.icon = new ImageIcon();
        this.contentPanel = new JPanel(new BorderLayout());
        this.separator = new JSeparator();
        this.welcomeTitle = new JLabel();
    }

    /**
     * @return contentPanel1.
     */
    public JPanel getContentPanel() {
        return this.contentPanel;
    }

    /**
     * @return imageIcon.
     */
    public ImageIcon getImageIcon() {
        ImageIcon imgIcon = new ImageIcon();
        imgIcon.setImage(Utility.getImage("images/jonasIcon.png"));
        return imgIcon;
    }

    /**
     * Underlines a text using HTML tags.
     * @param labelText the text to underline
     * @return a underlined text
     */
    public String underLineLabel(final String labelText) {
        return "<html><u>" + labelText + "</u></html>";
    }

    public JSeparator getSeparator() {
        return this.separator;
    }

    public JLabel getWelcomeTitle() {
        return this.welcomeTitle;
    }

    public ImageIcon getIcon() {
        return this.icon;
    }

    public JLabel getIconLabel() {
        return this.iconLabel;
    }

    public void setIcon(final ImageIcon icon) {
        this.icon = icon;
    }

    public int getSteps() {
        return this.steps;
    }

    public void setContentPanel(final JPanel contentPanel) {
        this.contentPanel = contentPanel;
    }

    public void makeFrame() {
    }
}
