/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasFieldFromWebsiteFrame.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.logging.Level;

import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSeparator;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.parser.Parser;
import org.ow2.jonas.autostart.utility.SpringUtilities;
import org.ow2.jonas.autostart.utility.Utility;

/**
 * This class creates main panel with gettingJonasFieldFromWebsiteFrame fields.
 * @author skabore
 */
public class GettingJonasFieldFromWebsiteFrame extends JPanel {

    /**
     * The JOnAS maven-metadata file URL.
     */
    private static final String JONAS_MAVEN_METADATA_FILE_URL = "http://repo1.maven.org/maven2/org/ow2/"
            + "jonas/assemblies/maven-metadata.xml";

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The JOnAS root label.
     */
    private JLabel jonasRootLabel;

    /**
     * The JOnAS base label.
     */
    private JLabel jonasBaseLabel;

    /**
     * The JOnAS version label.
     */
    private JLabel jonasVersionLabel;

    /**
     * The JOnAS type label.
     */
    private JLabel jonasTypeLabel;

    /**
     * The label.
     */
    private JLabel label;

    /**
     * The error label.
     */
    private JLabel errorLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The full radioButton.
     */
    private JRadioButton fullRadioButton;

    /**
     * The micro radioButton.
     */
    private JRadioButton microRadioButton;

    /**
     * The setJonasBase CheckBox.
     */
    private JCheckBox setJonasBaseCheckBox;

    /**
     * The includeJonasClient CheckBox.
     */
    private JCheckBox includeJonasClient;

    /**
     * The JOnAS version comboBox.
     */
    private JComboBox jonasVersionComboBox;

    /**
     * Setps to create a starter jar file.
     */
    private int steps;

    /**
     * The constructor.
     * @param steps, the required steps to create a starter
     */
    public GettingJonasFieldFromWebsiteFrame(final int steps) {

        super();
        this.steps = steps;

        contentPanel = getContentPanel();
        contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        ImageIcon icon = getImageIcon();

        titlePanel = new javax.swing.JPanel();
        textLabel = new javax.swing.JLabel();
        iconLabel = new javax.swing.JLabel();
        separator = new javax.swing.JSeparator();

        setLayout(new java.awt.BorderLayout());

        titlePanel.setLayout(new java.awt.BorderLayout());
        titlePanel.setBackground(Color.gray);

        textLabel.setBackground(Color.gray);
        textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        textLabel.setText("Download or copy JOnAS server file or folder");
        textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        textLabel.setOpaque(true);

        iconLabel.setBackground(Color.gray);
        if (icon != null) {
            iconLabel.setIcon(icon);
        }

        titlePanel.add(textLabel, BorderLayout.CENTER);
        titlePanel.add(new JLabel("5/" + this.steps + "  "), BorderLayout.EAST);
        titlePanel.add(separator, BorderLayout.SOUTH);

        add(titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return contentPanel1 the content panel.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel(new BorderLayout());

        jonasRootLabel = new JLabel("JOnAS Root ");
        jonasBaseLabel = new JLabel("JOnAS version ");
        jonasVersionLabel = new JLabel("JOnAS version ");
        jonasTypeLabel = new JLabel("JOnAS type    ");
        label = new JLabel(" Choose your version and type");
        errorLabel = new JLabel();
        errorLabel.setForeground(Color.red);
        ButtonGroup groupType = new ButtonGroup();
        fullRadioButton = new JRadioButton("full");
        microRadioButton = new JRadioButton("micro");
        groupType.add(fullRadioButton);
        groupType.add(microRadioButton);
        microRadioButton.setSelected(true);
        setJonasBaseCheckBox = new JCheckBox("Set JOnAS Base" + " (Advanced configuration)");
        setJonasBaseCheckBox.setEnabled(false);
        // setJonasBaseCheckBox.setSelected(true);
        includeJonasClient = new JCheckBox("Include JOnAS client ?" + " ($JONAS_ROOT/lib/client.jar)", false);
        includeJonasClient.setEnabled(false);
        List<String> jonasVersions = getJonasVersions();
        jonasVersions.add("");
        Collections.sort(jonasVersions);
        jonasVersionComboBox = new JComboBox((Object[]) jonasVersions.toArray());
        jonasVersionComboBox.setSelectedIndex(jonasVersions.size() - 1);

        contentPanel1.add(createFromWebsitePanel(), BorderLayout.CENTER);
        contentPanel1.add(errorLabel, BorderLayout.SOUTH);
        return contentPanel1;
    }

    /**
     * Create panel based on the FromWebsite option.
     * @return contentPanel
     */
    private JPanel createFromWebsitePanel() {
        JPanel content = new JPanel(new BorderLayout());
        JPanel applicationPanel = new JPanel(new SpringLayout());
        JPanel jonasVersionPanel = new JPanel(new SpringLayout());
        JPanel jonasTypePanel = new JPanel(new SpringLayout());
        JPanel jonasTypeFieldPanel = new JPanel(new SpringLayout());
        JPanel setJonasBaseFieldPanel = new JPanel(new SpringLayout());
        JPanel includeJonasClientPanel = new JPanel(new SpringLayout());

        jonasVersionLabel.setLabelFor(jonasVersionComboBox);
        jonasVersionPanel.add(jonasVersionLabel);
        jonasVersionPanel.add(jonasVersionComboBox);
        SpringUtilities.makeCompactGrid(jonasVersionPanel, 1, 2, 6, 0, 6, 0);

        jonasTypeLabel.setLabelFor(fullRadioButton);
        jonasTypeFieldPanel.add(fullRadioButton);
        jonasTypeFieldPanel.add(microRadioButton);
        SpringUtilities.makeCompactGrid(jonasTypeFieldPanel, 1, 2, 6, 0, 6, 0);
        jonasTypePanel.add(jonasTypeLabel);
        jonasTypePanel.add(jonasTypeFieldPanel);
        SpringUtilities.makeCompactGrid(jonasTypePanel, 1, 2, 6, 6, 6, 6);

        setJonasBaseFieldPanel.add(setJonasBaseCheckBox);
        SpringUtilities.makeCompactGrid(setJonasBaseFieldPanel, 1, 1, 6, 6, 6, 6);

        includeJonasClientPanel.add(includeJonasClient);
        SpringUtilities.makeCompactGrid(includeJonasClientPanel, 1, 1, 6, 6, 6, 6);

        applicationPanel.add(label);
        applicationPanel.add(new JLabel(" "));
        applicationPanel.add(jonasVersionPanel);
        applicationPanel.add(jonasTypePanel);
        applicationPanel.add(setJonasBaseFieldPanel);
        applicationPanel.add(includeJonasClientPanel);
        SpringUtilities.makeCompactGrid(applicationPanel, 6, 1, 6, 6, 6, 6);
        content.add(applicationPanel, BorderLayout.CENTER);
        return content;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * @return jonasBaseLabel
     */
    public JLabel getJonasBaseLabel() {
        return jonasBaseLabel;
    }

    /**
     * @return jonasRootLabel
     */
    public JLabel getJonasRootLabel() {
        return jonasRootLabel;
    }

    /**
     * @return label
     */
    public JLabel getLabel() {
        return label;
    }

    /**
     * @return errorLabel
     */
    public JLabel getErrorLabel() {
        return errorLabel;
    }

    /**
     * @return fullRadioButton
     */
    public JRadioButton getFullRadioButton() {
        return fullRadioButton;
    }

    /**
     * @return jonasVersionComboBox
     */
    public JComboBox getJonasVersionComboBox() {
        return jonasVersionComboBox;
    }

    /**
     * @return microRadioButton
     */
    public JRadioButton getMicroRadioButton() {
        return microRadioButton;
    }

    /**
     * @return setJonasBaseCheckBox
     */
    public JCheckBox getSetJonasBaseCheckBox() {
        return setJonasBaseCheckBox;
    }

    /**
     * @return includeJonasClient
     */
    public JCheckBox getIncludeJonasClientCheckBox() {
        return includeJonasClient;
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        jonasVersionComboBox.addActionListener(listener);
        microRadioButton.addActionListener(listener);
        fullRadioButton.addActionListener(listener);
        setJonasBaseCheckBox.addActionListener(listener);
        includeJonasClient.addActionListener(listener);
    }

    /**
     * @return the JOnAS latest version.
     */
    private List<String> getJonasVersions() {
        try {
            if (Utility.testConnexionURL(new URL(JONAS_MAVEN_METADATA_FILE_URL))) {
                // Utility.initProxyValues("", "", "", "");
                Parser parser = new Parser("http://repo1.maven.org/maven2/org/ow2/" + "jonas/assemblies/maven-metadata.xml",
                        "", "JOnAS");
                return parser.getAllLatestVersions();
            }
        } catch (MalformedURLException ex) {
            java.util.logging.Logger.getLogger(GettingJonasFieldFromWebsiteFrame.class.getName()).log(Level.SEVERE, null, ex);
        }
        return new ArrayList<String>();
    }
}
