/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasFieldFromZipFileFrame.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.awt.event.KeyListener;

import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSeparator;
import javax.swing.JTextField;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with gettingJonasFieldFromZipFile fields.
 * @author skabore
 */
public class GettingJonasFieldFromZipFileFrame extends JPanel {

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The label.
     */
    private JLabel label;

    /**
     * The error label.
     */
    private JLabel errorLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The zip file path.
     */
    private JTextField zipFilePath;

    /**
     * The zip file url.
     */
    private JTextField zipFileUrl;

    /**
     * The copy radioButton.
     */
    private JRadioButton copyRadioButton;

    /**
     * The download radioButton.
     */
    private JRadioButton downloadRadioButton;

    /**
     * The setJonasBase CheckBox.
     */
    private JCheckBox setJonasBaseCheckBox;

    /**
     * The includeJonasClient CheckBox.
     */
    private JCheckBox includeJonasClient;

    /**
     * The browse zip file button.
     */
    private JButton jbBrowseZipFile;

    /**
     * Setps to create a starter jar file.
     */
    private int steps;

    /**
     * The constructor.
     * @param builder the builder librairy
     * @param steps, the required steps to create a starter
     */
    public GettingJonasFieldFromZipFileFrame(final int steps) {
        super();
        this.steps = steps;
        contentPanel = getContentPanel();
        contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        ImageIcon icon = getImageIcon();

        titlePanel = new javax.swing.JPanel();
        textLabel = new javax.swing.JLabel();
        iconLabel = new javax.swing.JLabel();
        separator = new javax.swing.JSeparator();

        setLayout(new java.awt.BorderLayout());

        titlePanel.setLayout(new java.awt.BorderLayout());
        titlePanel.setBackground(Color.gray);

        textLabel.setBackground(Color.gray);
        textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        textLabel.setText("Download or copy JOnAS server file or folder");
        textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        textLabel.setOpaque(true);

        iconLabel.setBackground(Color.gray);
        if (icon != null) {
            iconLabel.setIcon(icon);
        }

        titlePanel.add(textLabel, BorderLayout.CENTER);
        titlePanel.add(new JLabel("5/" + this.steps + "  "), BorderLayout.EAST);
        titlePanel.add(separator, BorderLayout.SOUTH);

        add(titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return contentPanel1 the content panel.
     */
    private JPanel getContentPanel() {
        errorLabel = new JLabel("");
        errorLabel.setForeground(Color.red);
        zipFilePath = new JTextField(48);
        zipFileUrl = new JTextField();
        jbBrowseZipFile = new JButton("Browse...");
        label = new JLabel(" Set the zip file path or URL" + " (authorized extension \".zip\")");
        ButtonGroup groupCopy = new ButtonGroup();
        copyRadioButton = new JRadioButton("Copy zip file       ");
        downloadRadioButton = new JRadioButton("Download zip file");
        groupCopy.add(copyRadioButton);
        groupCopy.add(downloadRadioButton);
        copyRadioButton.setSelected(true);
        setJonasBaseCheckBox = new JCheckBox("Set JOnAS Base" + " (Advanced configuration)");
        // setJonasBaseCheckBox.setEnabled(false);
        includeJonasClient = new JCheckBox("Include JOnAS client ?" + " ($JONAS_ROOT/lib/client.jar)", false);
        includeJonasClient.setEnabled(false);

        JPanel contentPanel1 = new JPanel(new BorderLayout());
        contentPanel1.add(createFromExistingZipFilePanel(), BorderLayout.CENTER);
        contentPanel1.add(errorLabel, BorderLayout.SOUTH);
        return contentPanel1;
    }

    /**
     * Create panel based on the FromExistingZipFile option.
     * @return content
     */
    private JPanel createFromExistingZipFilePanel() {
        JPanel content = new JPanel();
        JPanel applicationPanel = new JPanel(new SpringLayout());
        JPanel jonasPathOptionPanel = new JPanel(new SpringLayout());
        JPanel jonasPathOptionFieldPanel = new JPanel(new SpringLayout());
        JPanel jonasUrlPanel = new JPanel(new SpringLayout());
        JPanel setJonasBaseFieldPanel = new JPanel(new SpringLayout());
        JPanel includeJonasClientPanel = new JPanel(new SpringLayout());

        jonasPathOptionPanel.add(copyRadioButton);
        jonasPathOptionFieldPanel.add(zipFilePath);
        jonasPathOptionFieldPanel.add(jbBrowseZipFile);
        SpringUtilities.makeCompactGrid(jonasPathOptionFieldPanel, 1, 2, 6, 0, 0, 0);
        jonasPathOptionPanel.add(jonasPathOptionFieldPanel);
        SpringUtilities.makeCompactGrid(jonasPathOptionPanel, 1, 2, 6, 6, 6, 6);

        jonasUrlPanel.add(downloadRadioButton);
        jonasUrlPanel.add(zipFileUrl);
        SpringUtilities.makeCompactGrid(jonasUrlPanel, 1, 2, 6, 0, 6, 0);

        setJonasBaseFieldPanel.add(setJonasBaseCheckBox);
        SpringUtilities.makeCompactGrid(setJonasBaseFieldPanel, 1, 1, 6, 6, 6, 6);

        includeJonasClientPanel.add(includeJonasClient);
        SpringUtilities.makeCompactGrid(includeJonasClientPanel, 1, 1, 6, 6, 6, 6);

        applicationPanel.add(label);
        applicationPanel.add(new JLabel(""));
        applicationPanel.add(jonasPathOptionPanel);
        applicationPanel.add(jonasUrlPanel);
        applicationPanel.add(setJonasBaseFieldPanel);
        applicationPanel.add(includeJonasClientPanel);
        SpringUtilities.makeCompactGrid(applicationPanel, 6, 1, 6, 6, 6, 6);
        enabledZipFileField();
        content.add(applicationPanel);
        return content;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * @return label the label text.
     */
    public JLabel getLabel() {
        return label;
    }

    /**
     * @return errorLabel the error label.
     */
    public JLabel getErrorLabel() {
        return errorLabel;
    }

    /**
     * @return copyRadioButton
     */
    public JRadioButton getCopyRadioButton() {
        return copyRadioButton;
    }

    /**
     * @return downloadRadioButton
     */
    public JRadioButton getDownloadRadioButton() {
        return downloadRadioButton;
    }

    /**
     * @return jbBrowseZipFile
     */
    public JButton getJbBrowseZipFile() {
        return jbBrowseZipFile;
    }

    /**
     * @return zipFilePath
     */
    public JTextField getZipFilePath() {
        return zipFilePath;
    }

    /**
     * @return zipFileUrl
     */
    public JTextField getZipFileUrl() {
        return zipFileUrl;
    }

    /**
     * @return setJonasBaseCheckBox
     */
    public JCheckBox getSetJonasBaseCheckBox() {
        return setJonasBaseCheckBox;
    }

    /**
     * @return includeJonasClient
     */
    public JCheckBox getIncludeJonasClientCheckBox() {
        return includeJonasClient;
    }

    /**
     * Enable zip file field.
     */
    public void enabledZipFileField() {
        jbBrowseZipFile.setEnabled(copyRadioButton.isSelected());
        zipFilePath.setEnabled(copyRadioButton.isSelected());
        zipFileUrl.setEnabled(!copyRadioButton.isSelected());
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        jbBrowseZipFile.addActionListener(listener);
        copyRadioButton.addActionListener(listener);
        downloadRadioButton.addActionListener(listener);
        setJonasBaseCheckBox.addActionListener(listener);
        includeJonasClient.addActionListener(listener);
    }

    /**
     * Add keyListener to the textfileds.
     * @param keyListener the keyListener.
     */
    @Override
    public void addKeyListener(final KeyListener keyListener) {
        zipFilePath.addKeyListener(keyListener);
        zipFileUrl.addKeyListener(keyListener);
    }
}
