/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: GettingJonasOptionFrame.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.Insets;
import java.awt.event.ActionListener;

import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JSeparator;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;

/**
 * This class creates main panel with option fields.
 * @author skabore
 */
public class GettingJonasOptionFrame extends JPanel {

    /**
     * The content panel.
     */
    private JPanel contentPanel;

    /**
     * The icon label.
     */
    private JLabel iconLabel;

    /**
     * The label.
     */
    private JLabel label;

    /**
     * The separator.
     */
    private JSeparator separator;

    /**
     * The text label.
     */
    private JLabel textLabel;

    /**
     * The title panel.
     */
    private JPanel titlePanel;

    /**
     * The fromDisk radioButton.
     */
    private JRadioButton fromDiskRadioButton;

    /**
     * The fromwebsiteDisk radioButton.
     */
    private JRadioButton fromWebsiteRadioButton;

    /**
     * The fromExistingZipFile radioButton.
     */
    private JRadioButton fromExistingZipFileRadioButton;

    /**
     * Setps to create a starter jar file.
     */
    private int steps;

    /**
     * The constructor.
     * @param steps, the required steps to create a starter
     */
    public GettingJonasOptionFrame(final int steps) {
        super();
        this.steps = steps;
        contentPanel = getContentPanel();
        contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        ImageIcon icon = getImageIcon();

        titlePanel = new javax.swing.JPanel();
        textLabel = new javax.swing.JLabel();
        iconLabel = new javax.swing.JLabel();
        separator = new javax.swing.JSeparator();

        setLayout(new java.awt.BorderLayout());

        titlePanel.setLayout(new java.awt.BorderLayout());
        titlePanel.setBackground(Color.gray);

        textLabel.setBackground(Color.gray);
        textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        textLabel.setText("Download or copy JOnAS server file or folder");
        textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        textLabel.setOpaque(true);

        iconLabel.setBackground(Color.gray);
        if (icon != null) {
            iconLabel.setIcon(icon);
        }

        titlePanel.add(textLabel, BorderLayout.CENTER);
        titlePanel.add(new JLabel("4/" + this.steps + "  "), BorderLayout.EAST);
        titlePanel.add(separator, BorderLayout.SOUTH);

        add(titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel();
        secondaryPanel.add(contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);
    }

    /**
     * @return contentPanel1 the content panel.
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel();
        JPanel applicationPanel = new JPanel(new SpringLayout());

        fromDiskRadioButton = new JRadioButton("From existing folder on disk");
        fromWebsiteRadioButton = new JRadioButton("From JOnAS website");
        fromExistingZipFileRadioButton = new JRadioButton("From existing" + " zip file");
        ButtonGroup groupCopy = new ButtonGroup();
        groupCopy.add(fromWebsiteRadioButton);
        fromWebsiteRadioButton.setSelected(true);
        groupCopy.add(fromDiskRadioButton);
        groupCopy.add(fromExistingZipFileRadioButton);
        label = new JLabel(" Choose your option to get JOnAS server");

        applicationPanel.add(label);
        applicationPanel.add(new JLabel(" "));
        applicationPanel.add(fromWebsiteRadioButton);
        applicationPanel.add(fromDiskRadioButton);
        applicationPanel.add(fromExistingZipFileRadioButton);
        SpringUtilities.makeCompactGrid(applicationPanel, 5, 1, 6, 0, 6, 0);
        contentPanel1.add(applicationPanel);
        return contentPanel1;
    }

    /**
     * @return imageIcon. the image icon.
     */
    private ImageIcon getImageIcon() {
        return null;
    }

    /**
     * @return fromDiskRadioButton
     */
    public JRadioButton getFromDiskRadioButton() {
        return fromDiskRadioButton;
    }

    /**
     * @return fromWebsiteRadioButton
     */
    public JRadioButton getFromWebsiteRadioButton() {
        return fromWebsiteRadioButton;
    }

    /**
     * @return fromExistingZipFileRadioButton
     */
    public JRadioButton getFromExistingZipFileRadioButton() {
        return fromExistingZipFileRadioButton;
    }

    /**
     * Add actionListener to the buttons.
     * @param listener the listener.
     */
    public void addActionListener(final ActionListener listener) {
        fromDiskRadioButton.addActionListener(listener);
        fromWebsiteRadioButton.addActionListener(listener);
        fromExistingZipFileRadioButton.addActionListener(listener);
    }
}
