/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2010 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: LicenseFrame.java 20819 2011-02-02 16:00:53Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.autostart.frame;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.GridLayout;
import java.awt.Insets;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.URL;
import java.util.logging.Level;
import java.util.logging.Logger;

import javax.swing.ButtonGroup;
import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.JTextArea;
import javax.swing.SpringLayout;
import javax.swing.border.EmptyBorder;

import org.ow2.jonas.autostart.utility.SpringUtilities;
import org.ow2.jonas.autostart.utility.Utility;

/**
 * This class creates main panel with License fields.
 * @author skabore
 */
public class LicenseFrame extends JPanel {

    /**
     * acceptLicense radioButton.
     */
    private JRadioButton acceptLicenseRadioButton;

    /**
     * doNotAcceptLicense radioButton.
     */
    private JRadioButton doNotAcceptLicenseRadioButton;

    /**
     * welcomeTitle panel.
     */
    private JLabel welcomeTitle;

    /**
     * contentPanel panel.
     */
    private JPanel contentPanel;

    /**
     * iconLabel label.
     */
    private JLabel iconLabel;

    /**
     * the separator.
     */
    private JSeparator separator;

    /**
     * text label.
     */
    private JLabel textLabel;

    /**
     * title panel.
     */
    private JPanel titlePanel;

    /**
     * license text.
     */
    private JTextArea licenseTexte;

    /**
     * The default constructor.
     */
    public LicenseFrame(final int steps) {

        super();

        contentPanel = getContentPanel();
        contentPanel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));

        titlePanel = new JPanel();
        textLabel = new JLabel();
        iconLabel = new JLabel();
        separator = new JSeparator();

        setLayout(new BorderLayout());

        titlePanel.setLayout(new BorderLayout());
        titlePanel.setBackground(Color.gray);

        textLabel.setBackground(Color.gray);
        textLabel.setFont(new Font("MS Sans Serif", Font.BOLD, 14));
        textLabel.setText("Licensing agreements");
        textLabel.setBorder(new EmptyBorder(new Insets(10, 10, 10, 10)));
        textLabel.setOpaque(true);

        iconLabel.setBackground(Color.gray);

        titlePanel.add(textLabel, BorderLayout.CENTER);
        titlePanel.add(new JLabel("2/" + steps + "   "), BorderLayout.EAST);
        titlePanel.add(separator, BorderLayout.SOUTH);

        add(titlePanel, BorderLayout.NORTH);
        JPanel secondaryPanel = new JPanel(new BorderLayout());
        secondaryPanel.add(contentPanel, BorderLayout.NORTH);
        add(secondaryPanel, BorderLayout.WEST);

    }

    /**
     * @return acceptLicenseRadioButton
     */
    public JRadioButton getAcceptLicenseRadioButton() {
        return acceptLicenseRadioButton;
    }

    /**
     * @return doNotAcceptLicenseRadioButton
     */
    public JRadioButton getDoNotAcceptLicenseRadioButton() {
        return doNotAcceptLicenseRadioButton;
    }

    /**
     * @return contentPanel1
     */
    private JPanel getContentPanel() {

        JPanel contentPanel1 = new JPanel(new BorderLayout());

        welcomeTitle = new JLabel(" Please read the following license" + " agreement carefully:");
        licenseTexte = new JTextArea(3, 85);
        licenseTexte.setEditable(false);
        licenseTexte.setPreferredSize(new Dimension(4, 85));

        ButtonGroup buttonGroup = new ButtonGroup();
        acceptLicenseRadioButton = new JRadioButton("I accept the terms of this license " + "agreement.");
        doNotAcceptLicenseRadioButton = new JRadioButton("I do not accept the terms of this license" + " agreement.");
        buttonGroup.add(acceptLicenseRadioButton);
        buttonGroup.add(doNotAcceptLicenseRadioButton);
        doNotAcceptLicenseRadioButton.setSelected(true);

        contentPanel1.add(welcomeTitle, BorderLayout.NORTH);

        JPanel licensePanel = new JPanel(new SpringLayout());
        JPanel applicationListPanel = new JPanel(new BorderLayout());

        URL licenseUrl = Utility.extractFile("license/license");
        JEditorPane editor = new JEditorPane();
        editor.setEditable(false);
        try {
            editor.setPage(licenseUrl);
        } catch (IOException ex) {
            Logger.getLogger(LicenseFrame.class.getName()).log(Level.SEVERE, null, ex);
        }
        JScrollPane scroll = new JScrollPane(editor);
        add(scroll, BorderLayout.CENTER);
        setVisible(true);
        scroll.setPreferredSize(new Dimension(825, 450));
        applicationListPanel.add(scroll, BorderLayout.CENTER);

        licensePanel.add(applicationListPanel);
        SpringUtilities.makeCompactGrid(licensePanel, 1, 1, 6, 0, 6, 0);
        contentPanel1.add(licensePanel, BorderLayout.CENTER);
        JPanel radionButton = new JPanel(new GridLayout(3, 0));
        radionButton.add(new JLabel(" "));
        radionButton.add(acceptLicenseRadioButton);
        radionButton.add(doNotAcceptLicenseRadioButton);
        contentPanel1.add(radionButton, BorderLayout.SOUTH);

        return contentPanel1;
    }

    /**
     * add actionListener the radio buttons.
     * @param listener the lister.
     */
    public void addCheckBoxActionListener(final ActionListener listener) {
        acceptLicenseRadioButton.addActionListener(listener);
        doNotAcceptLicenseRadioButton.addActionListener(listener);
    }
}
